==> mmaid-0.1.6.tar.gz: mmaid-0.1.6/autogen.sh <==
#!/bin/sh

progname=${0#./}
system=`(uname -s) 2>/dev/null`

gettextize='./.gettextize'
libtoolize='libtoolize'
libtool=
aclocal='aclocal'
aclocalo=
autoheader='autoheader'
automake='automake'
autoconf='autoconf'

case ${system} in
  Linux)
    if ! which ${aclocal} >/dev/null >/dev/null 2>/dev/null; then
      aclocal='aclocal-1.8'
    fi
    if ! which ${automake} >/dev/null 2>/dev/null; then
      automake='automake-1.8'
    fi
    ;;
  FreeBSD)
    libtool='/usr/local/share/aclocal/libtool.m4'
    if ! which ${aclocal} >/dev/null 2>/dev/null; then
      aclocal='aclocal14'
    fi
    aclocalo='-I m4'
    if ! which ${autoheader} >/dev/null 2>/dev/null; then
      autoheader='autoheader213'
    fi
    if ! which ${automake} >/dev/null 2>/dev/null; then
      automake='automake14'
    fi
    if ! which ${autoconf} >/dev/null 2>/dev/null; then
      autoconf='autoconf213'
    fi
    ;;
  Solaris)
    gettextize='gettextize'
    ;;
esac

echo "${progname}: gettextize..."
case ${system} in
  *)
    f="`which gettextize`"
    if test -f $f && test -x $f; then
      sed -e "/read dummy/D" $f > ${gettextize}
      chmod 755 ${gettextize}
    fi
    ;;
  Solaris)
    ;;
esac
${gettextize} --force --intl --no-changelog
case ${system} in
  *)
    rm -f ${gettextize}
    ;;
  Solaris)
    ;;
esac
if test -f Makefile.am~; then
  mv --force Makefile.am~ Makefile.am
fi
if test -f configure.ac~; then
  mv --force configure.ac~ configure.ac
fi

echo "${progname}: libtoolize..."
if test -f acinclude.m4; then
  mv --force acinclude.m4 acinclude.m4.original
  cp --force acinclude.m4.original acinclude.m4
fi
if ${libtoolize} --force && test ${libtool} && test -f ${libtool}; then
  cat ${libtool} >> acinclude.m4
fi

echo "${progname}: aclocal..."
${aclocal} ${aclocalo}
if test -f acinclude.m4.original; then
  mv --force acinclude.m4.original acinclude.m4
else
  rm --force acinclude.m4
fi

echo "${progname}: autoheader..."
${autoheader}

echo "${progname}: automake..."
${automake} --add-missing

echo "${progname}: autoconf..."
${autoconf}

==> mmaid-0.4.0.tar.gz: mmaid-0.4.0/autogen.sh <==
#!/bin/sh

progname=${0#./}
system=`(uname -s) 2>/dev/null`

gettextize='./.gettextize'
libtoolize='libtoolize'
libtool=
aclocal='aclocal'
aclocalo=
autoheader='autoheader'
automake='automake'
autoconf='autoconf'

case ${system} in
  Linux)
    if ! which ${aclocal} >/dev/null 2>/dev/null; then
      aclocal='aclocal-1.8'
    fi
    if ! which ${automake} >/dev/null 2>/dev/null; then
      automake='automake-1.8'
    fi
    ;;
  FreeBSD)
    libtool='/usr/local/share/aclocal/libtool.m4'
    if ! which ${aclocal} >/dev/null 2>/dev/null; then
      aclocal='aclocal14'
    fi
    aclocalo='-I m4'
    if ! which ${autoheader} >/dev/null 2>/dev/null; then
      autoheader='autoheader213'
    fi
    if ! which ${automake} >/dev/null 2>/dev/null; then
      automake='automake14'
    fi
    if ! which ${autoconf} >/dev/null 2>/dev/null; then
      autoconf='autoconf213'
    fi
    ;;
  Solaris)
    gettextize='gettextize'
    ;;
esac

echo "${progname}: gettextize..."
case ${system} in
  *)
    f="`which gettextize`"
    if test -f $f && test -x $f; then
      sed -e "/read dummy/D" $f > ${gettextize}
      chmod 755 ${gettextize}
    fi
    ;;
  Solaris)
    ;;
esac
${gettextize} --force --intl --no-changelog
case ${system} in
  *)
    rm -f ${gettextize}
    ;;
  Solaris)
    ;;
esac
if test -f Makefile.am~; then
  mv --force Makefile.am~ Makefile.am
fi
if test -f configure.ac~; then
  mv --force configure.ac~ configure.ac
fi

echo; echo; echo "${progname}: libtoolize..."
if test -f acinclude.m4; then
  mv --force acinclude.m4 acinclude.m4.original
  cp --force acinclude.m4.original acinclude.m4
fi
if ${libtoolize} --force && test ${libtool} && test -f ${libtool}; then
  cat ${libtool} >> acinclude.m4
fi

echo; echo; echo "${progname}: aclocal..."
${aclocal} ${aclocalo}
if test -f acinclude.m4.original; then
  mv --force acinclude.m4.original acinclude.m4
else
  rm --force acinclude.m4
fi

echo; echo; echo "${progname}: autoheader..."
${autoheader}

echo; echo; echo "${progname}: automake..."
${automake} --add-missing

echo; echo; echo "${progname}: autoconf..."
${autoconf}
